pub enum Error {
IntervalStepthroughOutOfBounds(String, Coordinate, Number),
Interval(Error),
InvalidIntervalPair(Error),
MisalignedDataSection,
Sequence(Error),
}Expand description
An error related to stepping through liftover segments.
Variants
IntervalStepthroughOutOfBounds(String, Coordinate, Number)
When stepping through the interval step through, moving the coordinates
returned None, which indicates there was an out of bounds somewhere.
Interval(Error)
An interval error.
InvalidIntervalPair(Error)
An error occurred when constructing a ContiguousIntervalPair.
MisalignedDataSection
The data section does not cumulative add up the specified end coordinates. This indicates a malformed data section.
Sequence(Error)
A sequence error.